import asyncio
from typing import List

from .argument_parser import parse_arguments


__title__ = "sub-do"
__version__ = "0.2.0"


async def run_in(folder, command):
    """Run command in folder."""
    process = await asyncio.create_subprocess_shell(
        command,
        stdout=asyncio.subprocess.PIPE,
        stderr=asyncio.subprocess.PIPE,
        cwd=folder)

    stdout, stderr = await process.communicate()

    print(f'[{command!r} in {folder}/ exited with {process.returncode}]')
    if stdout:
        print(f'[stdout]\n{stdout.decode()}')
    if stderr:
        print(f'[stderr]\n{stderr.decode()}')


async def run(folders: List[str], command: str) -> None:
    """Run command in the specified subfolders of the current folder."""
    await asyncio.gather(*(run_in(folder, command) for folder in folders))


def sub_do() -> None:
    """Main entry point for Sub-do."""
    parser, namespace = parse_arguments(__version__)
    asyncio.run(run(namespace.directory, namespace.command))
