"""Sub-do command-line argument parser."""

import argparse
import os
import shutil
from typing import Tuple


class SubDoArgumentParser(argparse.ArgumentParser):
    """Sub-do argument parser."""
    
    def __init__(self, version: str) -> None:
        super().__init__(
            epilog="When using -d, use -- to separate directories from the command or put the command first")
        self.add_argument("-V", "--version", action="version", version=f"%(prog)s {version}")
        default_dirs = [dir for dir in os.listdir() if os.path.isdir(dir) and not dir.startswith(".")]
        self.add_argument("-d", "--directory", metavar="directory", nargs="*", default=default_dirs,
                          help="directories to run the command in (default: all subdirectories except those whose "
                          "names begin with a dot)")
        self.add_argument("command", help="command to run")


def parse_arguments(version: str) -> Tuple[argparse.ArgumentParser, argparse.Namespace]:
    """Build the argument parser and parse the command line arguments."""

    # Ensure that the help info is printed using all columns available
    os.environ['COLUMNS'] = str(shutil.get_terminal_size().columns)
    parser = SubDoArgumentParser(version)
    namespace, remaining_args = parser.parse_known_args()
    if remaining_args:
        namespace.command += " " + " ".join(remaining_args)
    return parser, namespace
