"""Unit tests for the argument parser."""

import sys
import unittest
from unittest.mock import call, patch

from sub_do import argument_parser, __version__


class ArgumentParserTestCase(unittest.TestCase):
    """Unit tests for the argument parser."""

    @patch("sys.argv", new=["sub-do"])
    def test_usage(self):
        """Test the usage string."""
        self.assertEqual("usage: sub-do [-h] [-V] [-d [directory [directory ...]]] command\n", 
                         argument_parser.SubDoArgumentParser(__version__).format_usage())

    @patch("sys.argv", new=["sub-do", "-h"])
    @patch.object(sys.stdout, "write")
    def test_help(self, mock_stdout_write):
        """Test the help option."""
        self.assertRaises(SystemExit, argument_parser.parse_arguments, __version__)
        self.assertTrue(mock_stdout_write.call_args_list[0].startswith("uage: sub-do"))
                         
    @patch("sys.argv", new=["sub-do", "-V"])
    @patch.object(sys.stdout, "write")
    def test_version(self, mock_stdout_write):
        """Test the version option."""
        self.assertRaises(SystemExit, argument_parser.parse_arguments, __version__)
        self.assertTrue(mock_stdout_write.call_args_list[0].startswith(f"sub-do {__version__}"))

    @patch("sys.argv", new=["sub-do", "command"])
    def test_command(self):
        """Test the command argument."""
        namespace = argument_parser.parse_arguments(__version__)[1]
        self.assertEqual("command", namespace.command)

    @patch("sys.argv", new=["sub-do", "command", "command-argument"])
    def test_command_arguments(self):
        """Test the command argument."""
        namespace = argument_parser.parse_arguments(__version__)[1]
        self.assertEqual("command command-argument", namespace.command)

    @patch("sys.argv", new=["sub-do", "-d", "directory", "--", "command"])
    def test_directory(self):
        """Test the directory option."""
        namespace = argument_parser.parse_arguments(__version__)[1]
        self.assertEqual(["directory"], namespace.directory)
        